Release Notes
=============

0.1.0 (2018-12-18)
---------------------

- Adds CometML skorch callback
- Adds NeptuneML skorch callback
- Adds LRFinder skorch callback
- Adds LRRecorder skorch callback
- Adds TensorboardXLogger skorch callback
